@@ -411,6 +411,42 @@ class Base(Controller):
             print(f'Saving {lines_to_save} lines from history to snippet {snippet_name}')
             
             hist_save(lines_to_save, snippet_name, n_lines=n_lines)
+            
+    # function fd (fake data) to generate fake data based on a template or clipboard
+    @ex(
+        help='Generate fake data',
+        arguments=[
+            (['-n'],{
+                "help" : "Number of lines to generate",
+                "action" : "store"
+            }),
+            (['-t','--template'],{
+                "help" : "Path to template for data generation",
+                "action" : "store"
+            }),
+            (['-c','--columns'],{
+                "help" : "Whether column names are",
+                "action" : "store_true"
+            }),
+            (['--csv'],{
+                'help' : "Whether to generate csv", 
+                "action" : "store_true"}),
+            (['-d'],{
+                "help" : "Delimiter for the generated data",
+                "action" : "store"
+            })
+        ]
+    )
+    def fd(self):
+        from ..ext.faker import generate_fake_data
+        n_lines = int(self.app.pargs.__dict__.get('n') or 10)
+        template = self.app.pargs.__dict__.get('t') or self.app.pargs.__dict__.get('template')
+        columns = self.app.pargs.__dict__.get('c') or self.app.pargs.__dict__.get('columns')
+        csv = self.app.pargs.__dict__.get('csv')
+        
+        delimiter = self.app.pargs.__dict__.get('d') or ','
+        generate_fake_data(n_lines, template, delimiter, columns, csv)
+        
 
     @ex(
         help='Operations with snippets',
@@ -453,7 +489,7 @@ class Base(Controller):
             run_command(n_lines)
             
     @ex(
-        help='Operations with s3 bucket creationlabs-raw-data',
+        help='Operations with s3 buckets',
         arguments=[
             (['action'],{
                 "help" : "One of {ls, link}",
